package dk.nsp.idsas.util;

import org.apache.log4j.Logger;

import javax.xml.namespace.QName;
import javax.xml.soap.*;

public class SoapFaultGenerator {
	public enum FaultCode {
		NO_FAULT_CODE("Ingen fejlkode"),
		AUTH_FAILED("Autentificeringsfejl");

		private final String detail;
		FaultCode(String detail) {
			this.detail = detail;
		}

		public String getDetail() {
			return detail;
		}
	}

	private static Logger logger = Logger.getLogger(SoapFaultGenerator.class);
	
	public static SOAPFault generateSOAPFault(boolean client, String message, FaultCode faultCode) {
		final String faultMessage = message != null ? message : "No description";
		final FaultCode faultCodeString = faultCode != null ? faultCode : FaultCode.NO_FAULT_CODE;

		SOAPFault soapFault = null;
		try {
			final SOAPFactory soapFactory = SOAPFactory.newInstance();
			soapFault = soapFactory.createFault(faultMessage,
					new QName(SOAPConstants.URI_NS_SOAP_1_1_ENVELOPE, client ? "Client" : "Server"));
			soapFault.addTextNode(faultCodeString.getDetail());
		} catch (SOAPException e) {
			logger.error("Error generating SOAPFault: " + e.getMessage());
		}

		return soapFault;
	}

	public static String getWhitelistError(String cvr, WhitelistType whitelistType) {
		return String.format("CVR '%s' er ikke whitelisted for type %s", cvr, whitelistType);
	}

}
