package dk.nsp.idsas.ws._20230601;

import dk.nsp.idsas.security.IdsasContext;
import dk.nsp.idsas.security.IdsasContextBuilder;
import dk.nsp.idsas.util.WhitelistType;
import dk.nsp.idsas.ws.IdsasAbstractWS;
import dk.sundhedsdatastyrelsen.identitetssloering._2023._06._01.CreateBlurringRequestType;
import dk.sundhedsdatastyrelsen.identitetssloering._2023._06._01.EmptyRequest;
import dk.sundhedsdatastyrelsen.identitetssloering._2023._06._01.GetSaltRequestType;
import dk.sundhedsdatastyrelsen.identitetssloering._2023._06._01.IdsasServicePortType;
import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;

import javax.jws.WebService;
import javax.servlet.annotation.WebServlet;
import javax.xml.ws.BindingType;
import javax.xml.ws.soap.Addressing;

import static javax.xml.ws.soap.SOAPBinding.SOAP11HTTP_BINDING;

@WebServlet(name="IdsasService", urlPatterns={"/20230601/service"})
@WebService(serviceName = "IdsasService", wsdlLocation = "wsdl/20230601/idsas-service.wsdl",
        targetNamespace = "http://sundhedsdatastyrelsen.dk/identitetssloering/2023/06/01/",
        portName = "IdsasServicePort")
@BindingType(value = SOAP11HTTP_BINDING)
@Addressing(enabled = true, required = false)
public class IdsasServiceWS extends IdsasAbstractWS implements IdsasServicePortType {
    private static final Logger logger = Logger.getLogger(IdsasServiceWS.class);

    @Autowired
    private IdsasContextBuilder idsasContextBuilder;

    @Override
    public String createBlurring(CreateBlurringRequestType createBlurringRequest) {
        IdsasContext idsasContext = getValidatedIdsasContext(WhitelistType.BLURRING);
        logger.info(String.format("Enter create blurring for cvr '%s', patient '%s'", idsasContext.getActor().getCvr(), createBlurringRequest.getPatientId().getId()));
        return "OK";
    }

    @Override
    public String getSalt(GetSaltRequestType getSaltRequest) {
        IdsasContext idsasContext = getValidatedIdsasContext(WhitelistType.SALT);
        logger.info(String.format("Enter get salt for cvr '%s', date '%s'", idsasContext.getActor().getCvr(), getSaltRequest.getDateTime()));

        return "getSalt: " + getSaltRequest.getDateTime();
    }

    @Override
    public String getCurrentSalt(EmptyRequest getCurrentSaltRequest) {
        IdsasContext idsasContext = getValidatedIdsasContext(WhitelistType.SALT);
        logger.info(String.format("Enter get current salt for cvr '%s'", idsasContext.getActor().getCvr()));

        return "getCurrentSalt";
    }
}
